@@ -265,53 +265,49 @@ QByteArray HTMLFormElementImpl::formData(bool& ok)
 #endif
 
     QByteArray form_data;
-    form_data.resize(0);
-
-    QByteArray enc_string = ""; // used for non-multipart data
+    QByteArray enc_string; // used for non-multipart data
 
     bool useMultipart = m_multipart && m_post; // as multipart is ignored for GET
 
     // find out the QTextcodec to use
     QString str = m_acceptcharset.string();
-    const QChar space(' ');
-    const unsigned int strLength = str.length();
-    for(unsigned int i=0; i < strLength; ++i) if(str[i].toLatin1() == ',') str[i] = space;
-    const QStringList charsets = str.split(' ');
     QTextCodec* codec = 0;
-    KHTMLView *view = document()->view();
-    {
-        QStringList::ConstIterator it = charsets.begin();
-        const QStringList::ConstIterator itEnd = charsets.end();
+    bool codecOk = false;
 
-        for ( ; it != itEnd; ++it )
-        {
-            QString enc = (*it);
-            if(enc.contains("UNKNOWN"))
-            {
-                // use standard document encoding
-                enc = "ISO 8859-1";
-                if(view && view->part())
-                    enc = view->part()->encoding();
-            }
-            if((codec = KGlobal::charsets()->codecForName(enc.toLatin1().constData())))
-                break;
+    if (str == "UNKNOWN") {
+        // no accept-charset attribute, try document encoding
+        KHTMLView *view = document()->view();
+        if (view && view->part()) {
+            codec = KGlobal::charsets()->codecForName(view->part()->encoding(), codecOk);
         }
     }
-    if(!codec)
+
+    if (!codecOk) {
+        str.replace(QLatin1Char(','), QLatin1Char(' '));
+        const QStringList charsets = str.split(QLatin1Char(' '), QString::SkipEmptyParts);
+        for (QStringList::ConstIterator it = charsets.constBegin(); it != charsets.constEnd(); ++it) {
+            codec = KGlobal::charsets()->codecForName((*it), codecOk);
+            if (codecOk) {
+                break;
+            }
+        }
+    }
+
+    if (!codecOk) {
+        // none of requested could be used fallback to UTF-8
+        codec = KGlobal::charsets()->codecForName("UTF-8", codecOk);
+    }
+
+    if (!codecOk)
         codec = QTextCodec::codecForLocale();
 
     // we need to map visual hebrew to logical hebrew, as the web
     // server alsways expects responses in logical ordering
     if ( codec->mibEnum() == 11 )
-	codec = QTextCodec::codecForMib( 85 );
-
-    m_encCharset = codec->name();
-    const unsigned int m_encCharsetLength = m_encCharset.length();
-    for(unsigned int i=0; i < m_encCharsetLength; ++i)
-        m_encCharset[i] = m_encCharset[i].toLatin1() == ' ' ? QChar('-') : m_encCharset[i].toLower();
+        codec = QTextCodec::codecForMib( 85 );
 
     QStringList fileUploads, fileNotUploads;
-    
+
     /**
      Frameworks such as mootools Sortables expect form element values to be submitted in 
      tree order (and HTML5 specifies this behavior); however formElements need not be 
@@ -389,7 +385,7 @@ QByteArray HTMLFormElementImpl::formData(bool& ok)
                             const KMimeType::Ptr ptr = KMimeType::findByUrl(path);
                             if (!ptr->name().isEmpty()) {
                                 hstr += "\r\nContent-Type: ";
-                                hstr += ptr->name().toAscii().constData();
+                                hstr += ptr->name().toLatin1().constData();
                             }
                         } else if (!val.isEmpty()) {
                             fileNotUploads << path.pathOrUrl();
@@ -448,33 +444,31 @@ QByteArray HTMLFormElementImpl::formData(bool& ok)
     }
 
     if (useMultipart)
-        enc_string = QString("--" + m_boundary + "--\r\n").toAscii().constData();
-
-    const int old_size = form_data.size();
-    form_data.resize( form_data.size() + enc_string.length() );
-    memcpy(form_data.data() + old_size, enc_string.data(), enc_string.length() );
+        enc_string = QString("--" + m_boundary + "--\r\n").toLatin1().constData();
 
+    form_data.append(enc_string.constData());
     ok = true;
     return form_data;
 }
 
-void HTMLFormElementImpl::setEnctype( const DOMString& type )
+void HTMLFormElementImpl::setEnctype(const DOMString& type)
 {
-    if(type.string().indexOf("multipart", 0, Qt::CaseInsensitive) != -1 || type.string().indexOf("form-data", 0, Qt::CaseInsensitive) != -1)
-    {
+    if (type.isEmpty()) { // optimization: majority of real world cases
+        m_enctype = "application/x-www-form-urlencoded";
+        m_multipart = false;
+    }
+    else if (strcasecmp(type, "multipart/form-data") == 0) {
         m_enctype = "multipart/form-data";
         m_multipart = true;
-    } else if (type.string().indexOf("text", 0, Qt::CaseInsensitive) != -1 || type.string().indexOf("plain", 0, Qt::CaseInsensitive) != -1)
-    {
+    }
+    else if (strcasecmp(type, "text/plain") == 0) {
         m_enctype = "text/plain";
         m_multipart = false;
     }
-    else
-    {
+    else {
         m_enctype = "application/x-www-form-urlencoded";
         m_multipart = false;
     }
-    m_encCharset.clear();
 }
 
 static QString calculateAutoFillKey(const HTMLFormElementImpl& e)
@@ -532,7 +526,7 @@ void HTMLFormElementImpl::walletOpened(KWallet::Wallet *w) {
                     !current->readOnly() &&
                     map.contains(current->name().string())) {
                 document()->setFocusNode(current);
-                current->setValue(map[current->name().string()]);
+                current->setValue(map.value(current->name().string()));
             }
         }
     }
@@ -665,11 +659,11 @@ void HTMLFormElementImpl::submit(  )
                 if (w->hasFolder(KWallet::Wallet::FormDataFolder())) {
                     w->setFolder(KWallet::Wallet::FormDataFolder());
                     QMap<QString, QString> map;
-                    if (!w->readMap(key, map)) {
+                    if ( !w->readMap(key, map) && (map.count() == m_walletMap.count()) ) {
                         QMap<QString, QString>::const_iterator it = map.constBegin();
                         const QMap<QString, QString>::const_iterator itEnd = map.constEnd();
                         for ( ; it != itEnd; ++it )
-                            if ( map[it.key()] != m_walletMap[it.key()] ) {
+                            if ( it.value() != m_walletMap.value(it.key()) ) {
                                 login_changed = true;
                                 break;
                             }
